"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const MainContainer_1 = __importDefault(require("../../containers/MainContainer"));
const BalancesWidget_1 = __importDefault(require("../../widgets/BalancesWidget"));
const LinksWidget_1 = __importDefault(require("../../widgets/LinksWidget"));
const PaymentWidget_1 = __importDefault(require("../../widgets/PaymentWidget"));
const FundWidget_1 = __importDefault(require("../../widgets/FundWidget"));
const _web_integration_contexts_1 = require("../../contexts");
const _web_integration_constants_1 = require("../../constants");
const HypernetIFrameProxy_1 = __importDefault(require("../proxy/HypernetIFrameProxy"));
const ConnectorAuthorizationFlow_1 = __importDefault(require("../../flows/ConnectorAuthorizationFlow"));
class HypernetWebIntegration {
    constructor(iframeURL) {
        this.iframeURL = "http://localhost:8090";
        this.iframeURL = iframeURL || this.iframeURL;
        // Create a proxy connection to the iframe
        this.core = new HypernetIFrameProxy_1.default(this._prepareIFrameContainer(), this.iframeURL);
    }
    getReady() {
        if (this.getReadyResult != null) {
            return this.getReadyResult;
        }
        this.getReadyResult = this.core
            .activate()
            .andThen(() => {
            return this.core.activate();
        })
            .andThen(() => {
            return this.core.getEthereumAccounts();
        })
            .andThen((accounts) => this.core.initialize(accounts[0]))
            .map(() => this.core);
        return this.getReadyResult;
    }
    // This class must be used as a singleton, this enforces that restriction.
    static getInstance() {
        if (HypernetWebIntegration.instance == null) {
            HypernetWebIntegration.instance = new HypernetWebIntegration();
        }
        return HypernetWebIntegration.instance;
    }
    _generateDomElement(selector) {
        this._removeExistedElement(selector);
        const element = document.createElement("div");
        element.setAttribute("id", selector);
        document.body.appendChild(element);
        document.getElementById(selector);
        return element;
    }
    _removeExistedElement(selector) {
        const element = document.getElementById(selector);
        if (element) {
            element.remove();
        }
    }
    _bootstrapComponent(component, withModal = false) {
        return (react_1.default.createElement(_web_integration_contexts_1.StoreProvider, { proxy: this.core },
            react_1.default.createElement(_web_integration_contexts_1.LayoutProvider, null,
                react_1.default.createElement(MainContainer_1.default, { withModal: withModal }, component))));
    }
    _prepareIFrameContainer() {
        // Create a container element for the iframe proxy
        const iframeContainer = document.createElement("div");
        iframeContainer.id = "__hypernet-protocol-iframe-container__";
        // Add close modal icon to iframe container
        const closeButton = document.createElement("div");
        closeButton.id = "__hypernet-protocol-iframe-close-icon__";
        //@ts-ignore
        closeButton.innerHTML = `
      <img src="https://res.cloudinary.com/dqueufbs7/image/upload/v1611371438/images/Close-512.png" width="20" />
    `;
        iframeContainer.appendChild(closeButton);
        closeButton.addEventListener("click", (e) => {
            this.core.onMerchantIFrameClosed.next();
        }, false);
        // Add iframe modal style
        // TODO: Close button style is not responsive with the content height, need to be fixed.
        const style = document.createElement("style");
        style.appendChild(document.createTextNode(`
        iframe {
          position: absolute;
          display: none;
          border: none;
          width: 700px;
          height: 800px;
          min-height: 200px;
          background-color: white;
          top: 50%;
          left: 50%;
          box-shadow: 0px 4px 20px #000000;
          border-radius: 4px;
          transform: translate(-50%, -50%);
          padding: 15px;
        }
        #__hypernet-protocol-iframe-container__ {
          position: absolute;
          display: none;
          top: 0;
          left: 0;
          height: 100%;
          width: 100%;
          background-color: rgba(0,0,0,0.6);
        }
        #__hypernet-protocol-iframe-close-icon__ {
          position: absolute;
          top: 50%;
          left: 50%;
          transform: translate(calc(-50% + 335px), calc(-50% - 385px));
          z-index: 2;
          cursor: pointer;
        }
    `));
        document.head.appendChild(style);
        // Attach everything to the body
        document.body.appendChild(iframeContainer);
        return iframeContainer;
    }
    renderBalancesWidget(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this._bootstrapComponent(react_1.default.createElement(BalancesWidget_1.default, null)), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || _web_integration_constants_1.BALANCES_WIDGET_ID_SELECTOR));
        });
    }
    renderFundWidget(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this._bootstrapComponent(react_1.default.createElement(FundWidget_1.default, null)), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || _web_integration_constants_1.FUND_WIDGET_ID_SELECTOR));
        });
    }
    renderLinksWidget(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this._bootstrapComponent(react_1.default.createElement(LinksWidget_1.default, null)), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || _web_integration_constants_1.LINKS_WIDGET_ID_SELECTOR));
        });
    }
    renderPaymentWidget(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this._bootstrapComponent(react_1.default.createElement(PaymentWidget_1.default, { counterPartyAccount: config === null || config === void 0 ? void 0 : config.counterPartyAccount, amount: config === null || config === void 0 ? void 0 : config.amount, expirationDate: config === null || config === void 0 ? void 0 : config.expirationDate, requiredStake: config === null || config === void 0 ? void 0 : config.requiredStake, paymentTokenAddress: config === null || config === void 0 ? void 0 : config.paymentTokenAddress, merchantUrl: config === null || config === void 0 ? void 0 : config.merchantUrl, paymentType: config === null || config === void 0 ? void 0 : config.paymentType }), true), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || _web_integration_constants_1.PAYMENT_WIDGET_ID_SELECTOR));
        });
    }
    renderConnectorAuthorizationFlow(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this._bootstrapComponent(react_1.default.createElement(ConnectorAuthorizationFlow_1.default, { connectorUrl: config.connectorUrl, connectorName: config.connectorName, connectorLogoUrl: config.connectorLogoUrl }), config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || _web_integration_constants_1.BALANCES_WIDGET_ID_SELECTOR));
        });
    }
}
exports.default = HypernetWebIntegration;
window.HypernetWebIntegration = HypernetWebIntegration;
//# sourceMappingURL=HypernetWebIntegration.js.map