import { AcceptPaymentError, Balances, BigNumber, CoreUninitializedError, ControlClaim, EthereumAddress, RouterChannelUnknownError, HypernetLink, BlockchainUnavailableError, VectorError, LogicalError, PublicIdentifier, BalancesUnavailableError, PullPayment, PushPayment, InsufficientBalanceError, Payment, Result, ResultAsync, MerchantValidationError, PersistenceError } from "@hypernetlabs/hypernet-core";
import { Subject } from "rxjs";
import IHypernetIFrameProxy from "../../interfaces/proxy/IHypernetIFrameProxy";
import { ParentProxy } from "@hypernetlabs/utils";
export default class HypernetIFrameProxy extends ParentProxy implements IHypernetIFrameProxy {
    protected coreInitialized: boolean;
    protected isInControl: boolean;
    protected waitInitializedPromise: Promise<void>;
    protected _handshakePromise: Promise<void> | null;
    constructor(element: HTMLElement | null, iframeUrl: string);
    initialized(): Result<boolean, LogicalError>;
    waitInitialized(): ResultAsync<void, LogicalError>;
    inControl(): Result<boolean, LogicalError>;
    getEthereumAccounts(): ResultAsync<string[], BlockchainUnavailableError>;
    initialize(account: PublicIdentifier): ResultAsync<void, LogicalError>;
    getPublicIdentifier(): ResultAsync<PublicIdentifier, CoreUninitializedError>;
    depositFunds(assetAddress: EthereumAddress, amount: BigNumber): ResultAsync<Balances, BalancesUnavailableError | CoreUninitializedError | BlockchainUnavailableError | VectorError | Error>;
    withdrawFunds(assetAddress: EthereumAddress, amount: BigNumber, destinationAddress: EthereumAddress): ResultAsync<Balances, BalancesUnavailableError | CoreUninitializedError | BlockchainUnavailableError | VectorError | Error>;
    getBalances(): ResultAsync<Balances, BalancesUnavailableError | CoreUninitializedError>;
    getLinks(): ResultAsync<HypernetLink[], RouterChannelUnknownError | CoreUninitializedError | VectorError | Error>;
    getActiveLinks(): ResultAsync<HypernetLink[], RouterChannelUnknownError | CoreUninitializedError | VectorError | Error>;
    getLinkByCounterparty(counterPartyAccount: PublicIdentifier): Promise<HypernetLink>;
    sendFunds(counterPartyAccount: PublicIdentifier, amount: string, expirationDate: number, requiredStake: string, paymentToken: EthereumAddress, merchantUrl: string): ResultAsync<Payment, RouterChannelUnknownError | CoreUninitializedError | VectorError | Error>;
    authorizeFunds(counterPartyAccount: PublicIdentifier, totalAuthorized: BigNumber, expirationDate: number, deltaAmount: string, deltaTime: number, requiredStake: BigNumber, paymentToken: EthereumAddress, merchantUrl: string): ResultAsync<Payment, RouterChannelUnknownError | CoreUninitializedError | VectorError | Error>;
    acceptOffers(paymentIds: string[]): ResultAsync<Result<Payment, AcceptPaymentError>[], InsufficientBalanceError | AcceptPaymentError>;
    pullFunds(paymentId: string, amount: BigNumber): ResultAsync<Payment, RouterChannelUnknownError | CoreUninitializedError | VectorError | Error>;
    finalizePullPayment(paymentId: string, finalAmount: BigNumber): Promise<HypernetLink>;
    finalizePushPayment(paymentId: string): Promise<void>;
    initiateDispute(paymentId: string): ResultAsync<Payment, CoreUninitializedError>;
    mintTestToken(amount: BigNumber): ResultAsync<void, CoreUninitializedError>;
    authorizeMerchant(merchantUrl: string): ResultAsync<void, CoreUninitializedError | MerchantValidationError>;
    getAuthorizedMerchants(): ResultAsync<Map<string, string>, PersistenceError>;
    /**
     * Observables for seeing what's going on
     */
    onControlClaimed: Subject<ControlClaim>;
    onControlYielded: Subject<ControlClaim>;
    onPushPaymentProposed: Subject<PushPayment>;
    onPullPaymentProposed: Subject<PullPayment>;
    onPushPaymentUpdated: Subject<PushPayment>;
    onPullPaymentUpdated: Subject<PullPayment>;
    onPushPaymentReceived: Subject<PushPayment>;
    onPullPaymentApproved: Subject<PullPayment>;
    onBalancesChanged: Subject<Balances>;
    onMerchantAuthorized: Subject<string>;
    onAuthorizedMerchantUpdated: Subject<string>;
    onAuthorizedMerchantActivationFailed: Subject<string>;
    onMerchantIFrameDisplayRequested: Subject<string>;
    onMerchantIFrameCloseRequested: Subject<string>;
    onMerchantIFrameClosed: Subject<string>;
    onMerchantIFrameDisplayed: Subject<string>;
}
//# sourceMappingURL=HypernetIFrameProxy.d.ts.map